@@ -29,48 +29,49 @@
 ##' @seealso \code{\link{fosr}}
 ##' @keywords internal
 ##' @importFrom mgcv bam gam
+##' @importFrom MASS ginv
 amc <- function(y, Xmat, S, gam.method='REML', C=NULL, lambda=NULL, ...) {
   n.p = length(S)
   stopifnot( is.null(lambda) | length(lambda)==n.p )
   if (!is.null(C)) {
     # The following is based on Wood (2006), p. 186
-      n.con = dim(C)[1]
-      Z. = qr.Q(qr(t(C)), complete=TRUE)[ , -(1:n.con)]
-      Xmat. = Xmat %*% Z.
-      S. = vector("list", n.p)
-      #F: for (i in 1:n.p) S.[[i]] = crossprod(Z., S[[i]] %*% Z.)
-      #F: seems like mgcv >= 1.8.13
-      for (i in 1:n.p) {
+    n.con = dim(C)[1]
+    Z. = qr.Q(qr(t(C)), complete=TRUE)[ , -(1:n.con)]
+    Xmat. = Xmat %*% Z.
+    S. = vector("list", n.p)
+    for (i in 1:n.p) {
         if(is.null(lambda)) {
           S.[[i]] = list(crossprod(Z., S[[i]] %*% Z.))
         } else {
           S.[[i]] = list(crossprod(Z., S[[i]] %*% Z.), sp = lambda[i])
         }
-      }
-  }
-  else {
+    }
+  } else {
     Z. = diag(ncol(Xmat))
     Xmat. = Xmat
-    if(is.null(lambda)) {
-      S. = list(list(S[[1]]))
+    if (is.null(lambda)) {
+       S. = list(list(S[[1]]))
     } else {
-      S. = list(list(S[[1]], sp=lambda[1]))
-  }
+       S. = list(list(S[[1]], sp = lambda[1]))
+    }
   }
 
-    fitter = if (length(y) > 10000) bam else gam
-    #if (is.null(lambda)) fitobj = fitter(y ~ Xmat.-1, method=gam.method, paraPen=list(Xmat.=S.), ...)
-    #else
-    #fitobj = fitter(y ~ Xmat.-1, paraPen=list(Xmat.=S.), sp=lambda, ...)
-    fitobj = fitter(y ~ Xmat.-1, paraPen=list(Xmat.=S.[[1]]), ...)
+  fitter = if (length(y) > 10000) bam else gam
+  fitobj = fitter(y ~ Xmat.-1, paraPen=list(Xmat.=S.[[1]]), ...)
 
   lambdavec = if (!is.null(fitobj$full.sp)) fitobj$full.sp else fitobj$sp
   fullpen = 0
   for (i in 1:n.p) fullpen = lambdavec[i] * S.[[i]][[1]]
+  GinvXT <- try(Z. %*% solve(crossprod(Xmat.) + fullpen, t(Xmat.)), silent=TRUE)
+  if (inherits(GinvXT, "try-error")) {
+    warning(" 'X'X + penalty' is numerically rank-deficient.")
+    GinvXT <- Z. %*% ginv(crossprod(Xmat.) + fullpen, t(Xmat.))
+  }
+
   list(gam = fitobj,
-       coefficients = Z. %*% fitobj$coef,
-       Vp = Z. %*% fitobj$Vp %*% t(Z.),
-       GinvXT = Z. %*% solve(crossprod(Xmat.) + fullpen, t(Xmat.)),
-       method = gam.method)
+    coefficients = Z. %*% fitobj$coef,
+    Vp = Z. %*% fitobj$Vp %*% t(Z.),
+    GinvXT = GinvXT,
+    method = gam.method)
 }
 
