@@ -1,14 +1,14 @@
 #' Construct a PEER regression term in a \code{pfr} formula
 #'
 #' Defines a term \eqn{\int_{T}\beta(t)X_i(t)dt} for inclusion in a
-#' \code{\link{pfr}} formula, where \eqn{\beta(t)} is estimated with
+#' \code{{pfr}} formula, where \eqn{\beta(t)} is estimated with
 #' structured penalties (Randolph et al., 2012).
 #'
 #' @param X functional predictors, typically expressed as an \code{N} by \code{J} matrix,
 #'   where \code{N} is the number of columns and \code{J} is the number of
 #'   evaluation points. May include missing/sparse functions, which are
 #'   indicated by \code{NA} values. Alternatively, can be an object of class
-#'   \code{"fd"}; see \code{\link[fda]{fd}}.
+#'   \code{"fd"}; see \code{[fda]{fd}}.
 #' @param argvals indices of evaluation of \code{X}, i.e. \eqn{(t_{i1},.,t_{iJ})} for
 #'   subject \eqn{i}. May be entered as either a length-\code{J} vector, or as
 #'   an \code{N} by \code{J} matrix. Indices may be unequally spaced. Entering
@@ -31,7 +31,7 @@
 #'   an error.
 #'
 #' @details
-#' \code{peer} is a wrapper for \code{\link{lf}}, which defines linear
+#' \code{peer} is a wrapper for \code{{lf}}, which defines linear
 #' functional predictors for any type of basis. It simply calls \code{lf}
 #' with the appropriate options for the \code{peer} basis and penalty construction.
 #' The type of penalty is determined by the \code{pentype} argument. There
@@ -52,7 +52,7 @@
 #' }
 #'
 #' The original stand-alone implementation by Madan Gopal Kundu is available in
-#' \code{\link{peer_old}}.
+#' \code{{peer_old}}.
 #'
 #'
 #' @author Jonathan Gellar \email{JGellar@@mathematica-mpr.com} and
@@ -66,7 +66,7 @@
 #' Kundu, M. G., Harezlak, J., and Randolph, T. W. (2012). Longitudinal
 #' functional models with structured penalties (arXiv:1211.4763 [stat.AP]).
 #'
-#' @seealso \code{\link{pfr}}, \code{\link{smooth.construct.peer.smooth.spec}}
+#' @seealso \code{{pfr}}, \code{{.smooth.spec}}
 #' @export
 #' @examples
 #'
@@ -113,7 +113,7 @@ peer <- function(X, argvals=NULL, pentype="RIDGE",
     ret <- eval(call, envir=parent.frame())
     return(ret)
   }
-  
+
   if (is(X, "fd")) {
     # If X is an fd object, turn it back into a (possibly pre-smoothed) matrix
     if (is.null(argvals))
@@ -122,7 +122,7 @@ peer <- function(X, argvals=NULL, pentype="RIDGE",
     X <- t(eval.fd(argvals, X))
   } else if (is.null(argvals))
     argvals <- seq(0, 1, l = ncol(X))
-  
+
   if("xt" %in% names(dots)) stop("peer() does not accept an xt-argument.")
   xt <- call("list", pentype=pentype, W=substitute(X), phia=phia, L=L,
     Q=substitute(Q))
@@ -132,17 +132,17 @@ peer <- function(X, argvals=NULL, pentype="RIDGE",
 
 
 #' Basis constructor for PEER terms
-#' 
+#'
 #' Smooth basis constructor to define structured penalties (Randolph et al.,
 #' 2012) for smooth terms.
-#' 
-#' @param object a \code{peer.smooth.spec} object, usually generated by a 
+#'
+#' @param object a \code{peer.smooth.spec} object, usually generated by a
 #'   term \code{s(x, bs="peer")}; see Details.
 #' @param data a list containing the data (including any \code{by} variable)
 #'   required by this term, with names corresponding to \code{object$term}
 #'   (and \code{object$by}). Only the first element of this list is used.
 #' @param knots not used, but required by the generic \code{smooth.construct}.
-#' 
+#'
 #' @details The smooth specification object, defined using \code{s()}, should
 #'   contain an \code{xt} element. \code{xt} will be a list that contains
 #'   additional information needed to specify the penalty. The type of penalty
@@ -162,35 +162,35 @@ peer <- function(X, argvals=NULL, pentype="RIDGE",
 #'   \item \code{xt$pentype=="USER"} for a user-specified penalty matrix
 #'     \eqn{L}, supplied by \code{xt$L}.
 #' }
-#' 
+#'
 #' @return An object of class \code{"peer.smooth"}. See
-#'   \code{\link{smooth.construct}} for the elements that this object will
+#'   \code{{smooth.construct}} for the elements that this object will
 #'   contain.
 #' @author Madan Gopal Kundu \email{mgkundu@@iupui.edu} and Jonathan Gellar
-#' @seealso \code{\link{peer}}
+#' @seealso \code{{peer}}
 #' @references
 #' Randolph, T. W., Harezlak, J, and Feng, Z. (2012). Structured penalties for
 #' functional linear models - partially empirical eigenvectors for regression.
 #' \emph{Electronic Journal of Statistics}, 6, 323-353.
-#' 
+#'
 #' @export
 
-smooth.construct.peer.smooth.spec <- function(object, data, knots) {
+.smooth.spec <- function(object, data, knots) {
   # Constuctor Method for PEER basis and penalization
-  
+
   #if(!is.null(argvals))
   #  stop("argvals is not supported in the current version of refund.")
-  
+
   K <- length(data[[1]])
   k <- object$bs.dim
   m <- object$p.order
   xt <- object$xt
   pentype <- xt$pentype
   if (is.null(pentype)) pentype="RIDGE"
-  
+
   L <- if (toupper(pentype)=='DECOMP' | toupper(pentype)=='DECOMPOSITION') {
     # Decomposition Penalty
-    
+
     Q <- xt$Q
     phia <- xt$phia
     if (is.null(Q)) stop("Must enter a non-null Q matrix for DECOMP penalty")
@@ -198,12 +198,12 @@ smooth.construct.peer.smooth.spec <- function(object, data, knots) {
     else if (!is.numeric(phia)|is.matrix(phia))
       stop("Invalid entry for phia")
     if (ncol(Q) != K) stop("Width of Q matrix must match width of functions")
-    
+
     # Check singularity of Q matrix
-    Q <- Q[complete.cases(Q),]    
+    Q <- Q[complete.cases(Q),]
     Q.eig<- abs(eigen(Q %*% t(Q))$values)
     if(any(Q.eig<1e-12)) stop("Q matrix is singular or near singular")
-    
+
     P_Q <- t(Q) %*% solve(Q %*% t(Q)) %*% Q
     phia*(diag(K)- P_Q) + 1*P_Q
   } else if (toupper(pentype) %in% c("RIDGE", "NONE")) {
@@ -224,7 +224,7 @@ smooth.construct.peer.smooth.spec <- function(object, data, knots) {
     L <- xt$L
     if (is.null(L)) stop("Must enter a non-null L matrix for USER penalty")
     if (ncol(L) != K) stop("Width of L matrix must match width of functions")
-    
+
     # Check singularity of L matrix
     L <- L[complete.cases(L),]
     LL<- t(L)%*%L
@@ -234,7 +234,7 @@ smooth.construct.peer.smooth.spec <- function(object, data, knots) {
   } else {
     stop("Invalid pentype entry for PEER smooth")
   }
-  
+
   # Default k
   if (k<0) k <- K
   if (k==K) {
@@ -243,15 +243,15 @@ smooth.construct.peer.smooth.spec <- function(object, data, knots) {
     W <- xt$W
     v <- svd(data.matrix(W) %*% solve(L))$v[,1:k]
   }
-  
+
   D <- L %*% v
   D <- t(D) %*% D
   D <- (D + t(D))/2
-  
+
   # Return object
   object$X <- v
   object$S <- if (toupper(pentype)=="NONE") list() else list(D)
-  ## numerically determine null space dim -- seems safer than relying on m, 
+  ## numerically determine null space dim -- seems safer than relying on m,
   ## for pentype DECOMP and USER
   object$null.space.dim <- k - qr(D)$rank
   object$rank <- k - object$null.space.dim
@@ -263,11 +263,11 @@ smooth.construct.peer.smooth.spec <- function(object, data, knots) {
 }
 
 #' mgcv-style constructor for prediction of PEER terms
-#' 
+#'
 #' @param object a \code{peer.smooth} object created by
-#'   \code{\link{smooth.construct.peer.smooth.spec}}, see
-#'   \code{\link[mgcv]{smooth.construct}}
-#' @param data  see \code{\link[mgcv]{smooth.construct}}
+#'   \code{{.smooth.spec}}, see
+#'   \code{[mgcv]{smooth.construct}}
+#' @param data  see \code{[mgcv]{smooth.construct}}
 #' @return design matrix for PEER terms
 #' @author Jonathan Gellar
 #' @export
